@@ -43,11 +43,11 @@ class Block:
         self.start_time = int(time.time())
         self.block_time = 22
 
-        self.newly = False
-
         self.previous_hash = previous_hash
         self.sequance_number = 0
         self.empty_block_number = 0
+        self.hard_block_number = 2
+        self.gap_block_number = self.hard_block_number + 2
 
         self.validating_list = []
         self.transaction_fee = 0.02
@@ -60,6 +60,7 @@ class Block:
         self.part_amount = 100000
 
         self.hash = None
+        self.part_amount_cache = previous_hash
 
         self.max_tx_number = 2
         self.minumum_transfer_amount = 1000
@@ -77,6 +78,7 @@ class Block:
         self.validated_time = None
 
         self.dowload_true_block = ""
+        self.sync = False
 
     def reset_the_block(self, custom_nodes=None):
         """
@@ -85,7 +87,9 @@ class Block:
         and makes the edits for the new block.
         """
 
-        self.start_time = int(time.time())
+        self.start_time = (self.genesis_time +
+                           ((self.sequance_number + self.empty_block_number) *
+                            self.block_time)) + self.block_time
 
         self.round_1 = False
 
