@@ -7,7 +7,9 @@
 import time
 from hashlib import sha256
 
+from decentra_network.accounts.get_balance import GetBalance
 from decentra_network.accounts.get_sequance_number import GetSequanceNumber
+from decentra_network.blockchain.block.get_block import GetBlock
 from decentra_network.lib.log import get_logger
 from decentra_network.lib.settings_system import the_settings
 from decentra_network.transactions.get_transaction import GetTransaction
@@ -16,9 +18,6 @@ from decentra_network.wallet.ellipticcurve.ecdsa import Ecdsa
 from decentra_network.wallet.ellipticcurve.privateKey import PrivateKey
 from decentra_network.wallet.ellipticcurve.wallet_import import wallet_import
 
-from decentra_network.blockchain.block.get_block import GetBlock
-
-
 logger = get_logger("TRANSACTIONS")
 
 
@@ -31,6 +30,7 @@ def send(
     custom_current_time=None,
     custom_sequence_number=None,
     custom_balance=None,
+    custom_account_list=None,
 ):
     """
     The main function for sending the transaction.
@@ -44,7 +44,14 @@ def send(
     """
     block = block if block is not None else GetBlock()
 
-    amount = amount if amount is not None else block.minumum_transfer_amount
+    the_minumum_amount = 0
+    if (GetBalance(
+            block, to_user, account_list=custom_account_list,
+            dont_convert=True) >= 0):
+        pass
+    else:
+        the_minumum_amount = block.minumum_transfer_amount
+    amount = amount if amount is not None else the_minumum_amount
 
     try:
         amount = float(amount)
@@ -62,66 +69,58 @@ def send(
 
     decimal_amount = len(str(block.transaction_fee).split(".")[1])
     if len(str(amount).split(".")[1]) > decimal_amount:
-        logger.error(f"The amount of decimal places is more than {decimal_amount}.")
+        logger.error(
+            f"The amount of decimal places is more than {decimal_amount}.")
         return False
 
-    if amount >= block.minumum_transfer_amount:
-        if (
-            wallet_import(int(the_settings()["wallet"]), 2)
-            == sha256(password.encode("utf-8")).hexdigest()
-        ):
+    if (wallet_import(int(the_settings()["wallet"]),
+                      2) == sha256(password.encode("utf-8")).hexdigest()):
 
-            my_private_key = wallet_import(-1, 1, password)
-            my_public_key = "".join(
-                [
-                    l.strip()
-                    for l in wallet_import(-1, 0).splitlines()
-                    if l and not l.startswith("-----")
-                ]
-            )
+        my_private_key = wallet_import(-1, 1, password)
+        my_public_key = "".join([
+            l.strip() for l in wallet_import(-1, 0).splitlines()
+            if l and not l.startswith("-----")
+        ])
 
-            sequance_number = GetSequanceNumber(my_public_key) + 1
+        sequance_number = GetSequanceNumber(my_public_key) + 1
 
-            # Get the current fee
-            transaction_fee = block.transaction_fee
+        # Get the current fee
+        transaction_fee = block.transaction_fee
 
-            tx_time = int(time.time())
-            the_transaction = Transaction(
-                sequance_number,
-                Ecdsa.sign(
-                    (str(sequance_number) + my_public_key + str(to_user) + str(data))
-                    + str(amount)
-                    + str(transaction_fee)
-                    + str(tx_time),
-                    PrivateKey.fromPem(my_private_key),
-                ).toBase64(),
-                my_public_key,
-                to_user,
-                data,
-                amount,
-                transaction_fee,
-                tx_time,
-            )
+        tx_time = int(time.time())
+        the_transaction = Transaction(
+            sequance_number,
+            Ecdsa.sign(
+                (str(sequance_number) + my_public_key + str(to_user) +
+                 str(data)) + str(amount) + str(transaction_fee) +
+                str(tx_time),
+                PrivateKey.fromPem(my_private_key),
+            ).toBase64(),
+            my_public_key,
+            to_user,
+            data,
+            amount,
+            transaction_fee,
+            tx_time,
+        )
 
-            if GetTransaction(
+        if GetTransaction(
                 block,
                 the_transaction,
                 custom_current_time=custom_current_time,
                 custom_sequence_number=custom_sequence_number,
                 custom_balance=custom_balance,
-            ):
+                custom_account_list=custom_account_list,
+        ):
 
-                del my_private_key
-                del password
-
-                return the_transaction
-            else:
-                logger.error("The transaction is not valid.")
-                return False
+            del my_private_key
+            del password
 
+            return the_transaction
         else:
-            logger.error("Password is not correct")
+            logger.error("The transaction is not valid.")
             return False
+
     else:
-        logger.error(f"The amount is too low. minumum:{block.minumum_transfer_amount}")
+        logger.error("Password is not correct")
         return False
